encoding="utf-8
# whereisthemouse

A simple Python package to **show mouse position and pixel value** on the desktop. 

Press `Alt` to copy the current mouse position and pixel value to the clipboard.

## Usage

```python
import whereisthemouse
whereisthemouse.start()
```

## Features

- Display current mouse position and pixel color value.
- Press `Alt` to copy the information to the clipboard.

## License

MIT License
